<a id="mypy-boto3-route53-recovery-readiness"></a>

# mypy-boto3-route53-recovery-readiness

[![PyPI - mypy-boto3-route53-recovery-readiness](https://img.shields.io/pypi/v/mypy-boto3-route53-recovery-readiness.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53-recovery-readiness)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-route53-recovery-readiness.svg?color=blue)](https://pypi.org/project/mypy-boto3-route53-recovery-readiness)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-route53-recovery-readiness?color=blue)](https://pypistats.org/packages/mypy-boto3-route53-recovery-readiness)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Route53RecoveryReadiness 1.18.62](https://boto3.amazonaws.com/v1/documentation/api/1.18.62/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-route53-recovery-readiness docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-route53-recovery-readiness](#mypy-boto3-route53-recovery-readiness)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Route53RecoveryReadiness` service.

```bash
python -m pip install boto3-stubs[route53-recovery-readiness]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[route53-recovery-readiness]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-readiness]'`

Both type checking and auto-complete should work for `Route53RecoveryReadiness`
service. No explicit type annotations required, write your `boto3` code as
usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[route53-recovery-readiness]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-readiness]'`

Both type checking and auto-complete should work for `Route53RecoveryReadiness`
service. No explicit type annotations required, write your `boto3` code as
usual. Auto-complete can be slow on big projects or if you have a lot of
installed `boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[route53-recovery-readiness]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-readiness]'`
- Run `mypy` as usual

Type checking should work for `Route53RecoveryReadiness` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[route53-recovery-readiness]` in your environment:
  `python -m pip install 'boto3-stubs[route53-recovery-readiness]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Route53RecoveryReadiness` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`Route53RecoveryReadinessClient` provides annotations for
`boto3.client("route53-recovery-readiness")`.

```python
import boto3

from mypy_boto3_route53_recovery_readiness import Route53RecoveryReadinessClient

client: Route53RecoveryReadinessClient = boto3.client("route53-recovery-readiness")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: Route53RecoveryReadinessClient = session.client("route53-recovery-readiness")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_route53_recovery_readiness.paginator` module contains type
annotations for all paginators.

```python
from mypy_boto3_route53_recovery_readiness import Route53RecoveryReadinessClient
from mypy_boto3_route53_recovery_readiness.paginator import (
    GetCellReadinessSummaryPaginator,
    GetReadinessCheckResourceStatusPaginator,
    GetReadinessCheckStatusPaginator,
    GetRecoveryGroupReadinessSummaryPaginator,
    ListCellsPaginator,
    ListCrossAccountAuthorizationsPaginator,
    ListReadinessChecksPaginator,
    ListRecoveryGroupsPaginator,
    ListResourceSetsPaginator,
    ListRulesPaginator,
)

client: Route53RecoveryReadinessClient = boto3.client("route53-recovery-readiness")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_cell_readiness_summary_paginator: GetCellReadinessSummaryPaginator = client.get_paginator("get_cell_readiness_summary")
get_readiness_check_resource_status_paginator: GetReadinessCheckResourceStatusPaginator = client.get_paginator("get_readiness_check_resource_status")
get_readiness_check_status_paginator: GetReadinessCheckStatusPaginator = client.get_paginator("get_readiness_check_status")
get_recovery_group_readiness_summary_paginator: GetRecoveryGroupReadinessSummaryPaginator = client.get_paginator("get_recovery_group_readiness_summary")
list_cells_paginator: ListCellsPaginator = client.get_paginator("list_cells")
list_cross_account_authorizations_paginator: ListCrossAccountAuthorizationsPaginator = client.get_paginator("list_cross_account_authorizations")
list_readiness_checks_paginator: ListReadinessChecksPaginator = client.get_paginator("list_readiness_checks")
list_recovery_groups_paginator: ListRecoveryGroupsPaginator = client.get_paginator("list_recovery_groups")
list_resource_sets_paginator: ListResourceSetsPaginator = client.get_paginator("list_resource_sets")
list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
```

<a id="literals"></a>

### Literals

`mypy_boto3_route53_recovery_readiness.literals` module contains literals
extracted from shapes that can be used in user code for type checking.

```python
from mypy_boto3_route53_recovery_readiness.literals import (
    GetCellReadinessSummaryPaginatorName,
    GetReadinessCheckResourceStatusPaginatorName,
    GetReadinessCheckStatusPaginatorName,
    GetRecoveryGroupReadinessSummaryPaginatorName,
    ListCellsPaginatorName,
    ListCrossAccountAuthorizationsPaginatorName,
    ListReadinessChecksPaginatorName,
    ListRecoveryGroupsPaginatorName,
    ListResourceSetsPaginatorName,
    ListRulesPaginatorName,
    ReadinessType,
    ServiceName,
    PaginatorName,
)

def check_value(value: GetCellReadinessSummaryPaginatorName) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_route53_recovery_readiness.type_defs` module contains structures
and shapes assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_route53_recovery_readiness.type_defs import (
    CellOutputTypeDef,
    CreateCellRequestRequestTypeDef,
    CreateCellResponseTypeDef,
    CreateCrossAccountAuthorizationRequestRequestTypeDef,
    CreateCrossAccountAuthorizationResponseTypeDef,
    CreateReadinessCheckRequestRequestTypeDef,
    CreateReadinessCheckResponseTypeDef,
    CreateRecoveryGroupRequestRequestTypeDef,
    CreateRecoveryGroupResponseTypeDef,
    CreateResourceSetRequestRequestTypeDef,
    CreateResourceSetResponseTypeDef,
    DNSTargetResourceTypeDef,
    DeleteCellRequestRequestTypeDef,
    DeleteCrossAccountAuthorizationRequestRequestTypeDef,
    DeleteReadinessCheckRequestRequestTypeDef,
    DeleteRecoveryGroupRequestRequestTypeDef,
    DeleteResourceSetRequestRequestTypeDef,
    GetArchitectureRecommendationsRequestRequestTypeDef,
    GetArchitectureRecommendationsResponseTypeDef,
    GetCellReadinessSummaryRequestRequestTypeDef,
    GetCellReadinessSummaryResponseTypeDef,
    GetCellRequestRequestTypeDef,
    GetCellResponseTypeDef,
    GetReadinessCheckRequestRequestTypeDef,
    GetReadinessCheckResourceStatusRequestRequestTypeDef,
    GetReadinessCheckResourceStatusResponseTypeDef,
    GetReadinessCheckResponseTypeDef,
    GetReadinessCheckStatusRequestRequestTypeDef,
    GetReadinessCheckStatusResponseTypeDef,
    GetRecoveryGroupReadinessSummaryRequestRequestTypeDef,
    GetRecoveryGroupReadinessSummaryResponseTypeDef,
    GetRecoveryGroupRequestRequestTypeDef,
    GetRecoveryGroupResponseTypeDef,
    GetResourceSetRequestRequestTypeDef,
    GetResourceSetResponseTypeDef,
    ListCellsRequestRequestTypeDef,
    ListCellsResponseTypeDef,
    ListCrossAccountAuthorizationsRequestRequestTypeDef,
    ListCrossAccountAuthorizationsResponseTypeDef,
    ListReadinessChecksRequestRequestTypeDef,
    ListReadinessChecksResponseTypeDef,
    ListRecoveryGroupsRequestRequestTypeDef,
    ListRecoveryGroupsResponseTypeDef,
    ListResourceSetsRequestRequestTypeDef,
    ListResourceSetsResponseTypeDef,
    ListRulesOutputTypeDef,
    ListRulesRequestRequestTypeDef,
    ListRulesResponseTypeDef,
    ListTagsForResourcesRequestRequestTypeDef,
    ListTagsForResourcesResponseTypeDef,
    MessageTypeDef,
    NLBResourceTypeDef,
    PaginatorConfigTypeDef,
    R53ResourceRecordTypeDef,
    ReadinessCheckOutputTypeDef,
    ReadinessCheckSummaryTypeDef,
    RecommendationTypeDef,
    RecoveryGroupOutputTypeDef,
    ResourceResultTypeDef,
    ResourceSetOutputTypeDef,
    ResourceTypeDef,
    ResponseMetadataTypeDef,
    RuleResultTypeDef,
    TagResourceRequestRequestTypeDef,
    TargetResourceTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateCellRequestRequestTypeDef,
    UpdateCellResponseTypeDef,
    UpdateReadinessCheckRequestRequestTypeDef,
    UpdateReadinessCheckResponseTypeDef,
    UpdateRecoveryGroupRequestRequestTypeDef,
    UpdateRecoveryGroupResponseTypeDef,
    UpdateResourceSetRequestRequestTypeDef,
    UpdateResourceSetResponseTypeDef,
)

def get_structure() -> CellOutputTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-route53-recovery-readiness` version is the same as related `boto3`
version and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/)
format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-route53-recovery-readiness docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
